## Geosoup Machine Learning library v0.1.43

[![DOI](https://zenodo.org/badge/259178307.svg)](https://zenodo.org/badge/latestdoi/259178307)

Geosoup is a python package for geospatial data manipulation using `GDAL` and `GDAL bindings` in python. This library is the machine learning support for geosoup.

Currently implemented:

`Random Forest Regressor`  
`Multiple Linear Regressor`


Install using:

`pip install geosoupML`


_Note: Must have_ `GDAL >= 2.1.3` _up and running before installing geosoup and geosoupML._
